/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.protocol;


/**
 * <p>
 * Base class for <code>CA_PROTO_READ</code> messages.
 * </p>
 * 
 * <p>
 * This message type is used by clients to read from a channel and by servers to
 * reply to such a read request. This message type has been replaced by the
 * newer {@link ChannelAccessCommand#CA_PROTO_READ_NOTIFY CA_PROTO_READ_NOTIFY}
 * message type, so new clients should prefer that command.
 * </p>
 * 
 * @see ChannelAccessCommand#CA_PROTO_READ
 * @see ChannelAccessReadClientMessage
 * @see ChannelAccessReadServerMessage
 * 
 * @author Sebastian Marsching
 */
public abstract class ChannelAccessReadMessage extends ChannelAccessMessage {

    /**
     * Constructor. This constructor only sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_READ}. All other fields depend on
     * the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     */
    ChannelAccessReadMessage() {
        super(ChannelAccessCommand.CA_PROTO_READ);
    }

    /**
     * Constructor. This constructor sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_READ} and stores the message header
     * that is used to construct this message. All other fields depend on the
     * context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     * 
     * @param messageHeader
     *            the message header that is used to for creating this message.
     *            This header is passed on to the
     *            {@link ChannelAccessMessage#ChannelAccessMessage(ChannelAccessCommand, ChannelAccessMessageHeader)}
     *            constructor.
     */
    ChannelAccessReadMessage(ChannelAccessMessageHeader messageHeader) {
        super(ChannelAccessCommand.CA_PROTO_READ, messageHeader);
    }

}
