/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.protocol;


/**
 * <p>
 * Base class for <code>CA_PROTO_READ_NOTIFY</code> messages.
 * </p>
 * 
 * <p>
 * This message type is used by clients to read from a channel and by servers to
 * reply to such a read request. This message type replaces the older
 * {@link ChannelAccessCommand#CA_PROTO_READ CA_PROTO_READ} message type, that
 * new clients should not use any longer.
 * </p>
 * 
 * @see ChannelAccessCommand#CA_PROTO_READ_NOTIFY
 * @see ChannelAccessReadNotifyClientMessage
 * @see ChannelAccessReadNotifyServerMessage
 * 
 * @author Sebastian Marsching
 */
public abstract class ChannelAccessReadNotifyMessage extends
        ChannelAccessMessage {

    /**
     * Constructor. This constructor only sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_READ_NOTIFY}. All other fields
     * depend on the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     */
    ChannelAccessReadNotifyMessage() {
        super(ChannelAccessCommand.CA_PROTO_READ_NOTIFY);
    }

    /**
     * Constructor. This constructor sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_READ_NOTIFY} and stores the message
     * header that is used to construct this message. All other fields depend on
     * the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     * 
     * @param messageHeader
     *            the message header that is used to for creating this message.
     *            This header is passed on to the
     *            {@link ChannelAccessMessage#ChannelAccessMessage(ChannelAccessCommand, ChannelAccessMessageHeader)}
     *            constructor.
     */
    ChannelAccessReadNotifyMessage(ChannelAccessMessageHeader messageHeader) {
        super(ChannelAccessCommand.CA_PROTO_READ_NOTIFY, messageHeader);
    }

}
